#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: autopano-sift-c
# PROJECT HOMEPAGE 	: http://hugin.sourceforge.net/
# SOURCES          	: http://downloads.sourceforge.net/sourceforge/hugin/
#
# MAINTAINER       	: skywatcher (s.skywatcher|AT|gmail|DOT|org, simone antoniucci)
# LATEST REVISION	: 2011-01-18
#
# BUILD-ONLY DEPS	: cmake
# NOTES				: check deps for |

### Checking for unbound variables
set -u

### Setting main variables
NAME="autopano-sift-c"
VERSION="2.5.1"
ARCH="i486"
CPU="i686"
BUILD=70.1
EXT="txz"

NOME="autopano-sift-C"

HOMEPAGE="http://hugin.sourceforge.net/"
DESCRIPTION="Tool for creation of control points in hugin"
SRCLNK="http://downloads.sourceforge.net/sourceforge/hugin/$NOME-$VERSION.tar.gz"

CWD=`pwd`
PKGDIR=$CWD/$NAME-install
PKG=$NAME-$VERSION-$ARCH-$BUILD
SRCPKG=`echo $SRCLNK | rev | cut -d/ -f1 | rev`
SRCDIR=$CWD/$NOME-$VERSION
#~ ICONDIR=$PKGDIR/usr/share/icons/hicolor/48x48/apps/		

URL=http://zenwalk.pinguix.com/user-accounts/skywatcher/$NAME/$VERSION
DOCS="ChangeLog README* LICENSE doc/*.txt"

NJOBS="-j2"
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Mkdir
mkdir -p $PKGDIR
mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/doc/$NAME-$VERSION
mkdir -p $PKGDIR/usr/man/man1
mkdir -p $PKGDIR/usr/man/man7
mkdir -p $PKGDIR/usr/src/$NAME-$VERSION
#~ mkdir -p $PKGDIR/usr/share/applications
#~ mkdir -p $ICONDIR

### Checking if sources are present. If not, download them
if [ -f $SRCPKG ]; then
	echo "Source file is already present, no need to download it";
else
	echo "Downloading source..."
	wget -c -nv $SRCLNK
fi

### Extracting source
tar xfv $SRCPKG

### Building
cd $SRCDIR
cmake -DCMAKE_INSTALL_PREFIX=/usr . || exit 1
make $NJOBS || exit 1
make install DESTDIR=$PKGDIR || exit 1

### Stripping binaries
cd $PKGDIR
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Docs, man, info
cd $SRCDIR
cp -a $DOCS $PKGDIR/usr/doc/$NAME-$VERSION
mv $PKGDIR/usr/share/man/man7 $PKGDIR/usr/man/man7
mv $PKGDIR/usr/share/man/man1 $PKGDIR/usr/man/man1
rm -fr $PKGDIR/usr/share
find $PKGDIR/usr/man -type f -exec gzip -9 {} \;

### Adding build-file and other stuff to the package
cp -a $CWD/$0 $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh
chmod a+x $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME:  
$NAME: autopano-sift-C is a C port of the C# software autopano-sift. It
$NAME: creates control points for groups of overlapping photographs and it
$NAME: can be controlled from within the Hugin GUI front-end.
$NAME: 
$NAME: 
$NAME: 
$NAME: 
$NAME: 
$NAME: $HOMEPAGE
EOF

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

### Making the package
makepkg -l y -c n $CWD/$PKG.$EXT

### md5
cd $CWD
md5sum $PKG.$EXT > $PKG.md5

### dep
depfinder $PKG.$EXT > $PKG.dep

### txt
cat $PKGDIR/install/slack-desc > $PKG.txt

### src
rm -fr $PKG.src
for link in $URL/$0 $SRCLNK
	do echo $link >> $PKG.src
done

### Cleaning
rm -rf $SRCDIR
rm -rf $PKGDIR

### Done. Ciao!
